Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
var Args map[string]string
Args is a map of the args that were passed after the first arg with dash prefixes (e.g. -- or -) trimmed. A value is set for a member of Args if an arg is proceeded with an equality operator (e.g. --arg=value).
var CustomUsage string
CustomUsage allows you to add custom usage details. The value of CustomUsage is printed in between the name of the binary and the flags in the usage message.
Functions ¶
func PrintUsage ¶
func PrintUsage()
PrintUsage prints a usage message based on the arguments and usage you have registered then exits.
Types ¶
Click to show internal directories.
Click to hide internal directories.